@@ -596,12 +596,14 @@ clean_kill_applets (PanelWidget *panel)
 					     "applet_info");
 		if (info->type == APPLET_EXTERN) {
 			Extern *ext = info->data;
+			extern_save_last_position (ext, FALSE /* sync */);
 			ext->clean_remove = TRUE;
 		} else if (info->type == APPLET_SWALLOW) {
 			Swallow *swallow = info->data;
 			swallow->clean_remove = TRUE;
 		}
 	}
+	gnome_config_sync ();
 }
 
 static void
@@ -643,6 +645,8 @@ panel_destroy (GtkWidget *widget, gpointer data)
 		gtk_widget_unref (pd->menu);
 	pd->menu = NULL;
 
+	pd->panel = NULL;
+
 	panel_list = g_slist_remove (panel_list, pd);
 	g_free (pd);
 }
